@@ -84,7 +84,8 @@ class Escrow:
         return True
 
     #Refund user their collateral, remoing the fee
-    def finalizeEscrow(self):
+    def finalizeEscrow(self,fee=None):
+        if fee is None: fee=self.fee
         #Return money to deposit address
         returnAmount=self.getBalance(self.holdingAddress)
         
